<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
	register_activation_hook( __FILE__, 'rwmb_check_php_version' );

	/**
	 * Display notice for old PHP version.
	 */
	function rwmb_check_php_version() {
		if ( version_compare( phpversion(), '5.3', '<' ) ) {
			die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
		}
	}

	require_once dirname( __FILE__ ) . '/inc/loader.php';
	$rwmb_loader = new RWMB_Loader();
	$rwmb_loader->init();


	add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

	$prefix = '_cmb_';


  // Open Code


    $meta_boxes[] = array(

        'id'         => 'post_setting',

        'title'      => 'Post Setting',

        'pages'      => array('post'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(
            array(
                'name' => 'Select',
                'id'   => $prefix . 'post_select',
                'type'    => 'select',
                'options'   => array(
                    array( 'value' => '1', 'name' => 'No Sidebar' ),
                    array( 'value' => '', 'name' => 'Have Sidebar' ),
                    ),
            'placeholder'     => 'Select type sidebar',
                    ),

            array(

                'name' => 'Featured Image 2',

                'desc' => 'Show in sidebar',

                'id'   => $prefix . 'featured_image_2',

                'type'    => 'file',

            ),

            array(

                'name' => 'Featured Image 3',

                'desc' => 'Show in blog grid and home page',

                'id'   => $prefix . 'featured_image_3',

                'type'    => 'file',

            ),

            array(

                'name' => 'Link share facebook',

                'id'   => $prefix . 'single_facebook',

                'type'    => 'text',

            ),

            array(

                'name' => 'Link share twitter',

                'id'   => $prefix . 'single_twitter',

                'type'    => 'text',

            ),

            array(

                'name' => 'Link share pinterest',

                'id'   => $prefix . 'single_pinterest',

                'type'    => 'text',

            ),

            array(

                'name' => 'Link share linkedin',

                'id'   => $prefix . 'single_linkedin',

                'type'    => 'text',

            ),

          

        )

    );



$meta_boxes[] = array(

        'id'         => 'donation_setting',

        'title'      => 'Donation Setting',

        'pages'      => array('donation'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

            array(

                'name' => 'Thumbnail Image',

                'desc' => 'Show in project page',

                'id'   => $prefix . 'project_image',

                'type'    => 'file',

            ),

             array(

                'name' => 'Location',

                'desc' => '',

                'id'   => $prefix . 'location',

                'type'    => 'textarea',

            ),

             array(

                'name' => 'Raised',

                'desc' => '',

                'id'   => $prefix . 'raised',

                'type'    => 'textarea',

            ),

             array(

                'name' => 'Goal',

                'desc' => '',

                'id'   => $prefix . 'goal',

                'type'    => 'textarea',

            ),

             array(

                'name' => 'Percent',

                'desc' => '',

                'id'   => $prefix . 'percent',

                'type'    => 'text',

            ),

        )

    );

// End Code



    return $meta_boxes;
});
}
