<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAboutVersionTwo extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About Version Two', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs About widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs About widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'about' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'About Version Two', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'text_blur',
			[
				'label'       => __( 'Blur Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Blur Text', 'bdevs-elementor' ),
				'default'     => __( 'Blur Text', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Subheading', 'bdevs-elementor' ),
				'default'     => __( 'This is subheading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Heading', 'bdevs-elementor' ),
				'default'     => __( 'This is heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::WYSIWYG,
				'placeholder' => __( 'Content', 'bdevs-elementor' ),
				'default'     => __( 'This is content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Button', 'bdevs-elementor' ),
				'default'     => __( 'This is button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'link_button',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_video',
			[
				'label' => esc_html__( 'Project', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'title_donation',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Title', 'bdevs-elementor' ),
				'default'     => __( 'This is title', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_number',
			[
				'label'       => __( 'Projects Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Projects Count', 'bdevs-elementor' ),
				'default'     => __( '3', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_text_blur',
			[
				'label'   => esc_html__( 'Show Blur Text', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$post_number = $settings['post_number'];
	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'Donation',  'orderby' => 'ID', 'order' => 'ASC'));
	   
	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'Donation',  'orderby' => 'ID', 'order' => 'ASC');
		extract($settings); ?>
		<div class="about-area default-padding">
	        <div class="container">
	            <div class="row align-center">

	                <div class="col-lg-6 popular-causes">
	                    <div class="causes-box">
	                        <h4> <i class="fas fa-bolt"></i> <?php print wp_kses_post($settings['title_donation']); ?></h4>
	                        <?php
				                $args = new \WP_Query(array(   
				                            'post_type' => 'Donation', 
				                        ));  
				                while ($wp_query -> have_posts()) : $wp_query -> the_post();
				                $raised = get_post_meta(get_the_ID(),'_cmb_raised', true);
    							$goal = get_post_meta(get_the_ID(),'_cmb_goal', true);
    							$percent = get_post_meta(get_the_ID(),'_cmb_percent', true);
    							$location = get_post_meta(get_the_ID(),'_cmb_location', true);
    							$project_image = get_post_meta(get_the_ID(),'_cmb_project_image', true);
				            ?>
	                        <div class="item">
	                            <div class="thumb">
	                                <img src="<?php print wp_get_attachment_url($project_image); ?>" alt="Thumb">
	                            </div>
	                            <div class="info">
	                                <?php  $categories = get_the_terms(get_the_ID(),'type');
				                        foreach( (array)$categories as $categorie){

				                        $cat_name = $categorie->name; 
				                        $cat_slug = $categorie->slug;
				                        ?>
	                                    <span class="cats"><?php echo esc_attr($cat_name);?></span>
                                    <?php } ?>
	                                <h4>
	                                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
	                                </h4>
	                                <div class="progress-box">
	                                    <p><?php echo esc_attr($raised); ?> <span class="float-right"><?php echo esc_attr($goal); ?></span></p>
	                                    <div class="progress">
	                                        <div class="progress-bar" role="progressbar" data-width="<?php echo esc_attr($percent); ?>"></div>
	                                    </div>
	                                    <span>Fund collect : <?php echo esc_attr($percent); ?>%</span>
	                                </div>
	                            </div>
	                        </div>
	                        <?php   
						        endwhile; 
						        wp_reset_postdata();
						    ?>
	                    </div>
	                </div>

	                <div class="col-lg-6 info">
	                	<?php if ( $settings['show_subheading'] ) : ?>
		                <h5><?php print wp_kses_post($settings['subheading']); ?></h5>
		                <?php endif; ?>
		                <?php if ( $settings['show_text_blur'] ) : ?>
		                <h2 class="text-blur"><?php print wp_kses_post($settings['text_blur']); ?></h2>
		                <?php endif; ?>
		                <?php if ( $settings['show_heading'] ) : ?>
		                <h2 class="area-title"><?php print wp_kses_post($settings['heading']); ?></h2>
		                <?php endif; ?>
	                    <?php if ( $settings['show_content'] ) : ?>
		                <?php print wp_kses_post($settings['content']); ?>
		                <?php endif; ?>
	                    <?php if ( $settings['show_button'] ) : ?>
		                <a class="btn circle btn-theme border btn-md" href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a>
		            	<?php endif; ?>
	                </div>
	                
	            </div>
	        </div>
	    </div>
	<?php
	}

}