<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBlogVersionTwo extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog Version Two', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Blog widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Blog widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'blog' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Blog Version Two', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
				'default'		=> __('This is subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'		=> __('This is heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your content', 'bdevs-elementor' ),
				'default'		=> __('This is content', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Button', 'bdevs-elementor' ),
				'default'		=> __('Button', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'link_button',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Link Button', 'bdevs-elementor' ),
				'default'		=> __('#', 'bdevs-elementor'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '3',
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display(); 
		extract($settings);	
		$post_number = $settings['post_number'];
	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => 'ASC'));
	   
	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => 'ASC');	
	   	?>
	   	<!-- Start Blog 
	    ============================================= -->
	    <div class="blog-area default-padding bottom-less">
	        <div class="container">
	            <div class="heading-left">
	                <div class="row">
	                    <div class="col-lg-6 left-info">
	                        <?php if ( $settings['show_subheading'] ) : ?>
			                <h5><?php print wp_kses_post($settings['subheading']); ?></h5>
			                <?php endif; ?>
	                        <?php if ( $settings['show_heading'] ) : ?>
			                <h2><?php print wp_kses_post($settings['heading']); ?></h2>
			                <?php endif; ?>
	                    </div>
	                    <div class="col-lg-6 right-info">
	                    	<?php if ( $settings['show_content'] ) : ?>
	                        <p>
	                            <?php print wp_kses_post($settings['content']); ?>
	                        </p>
	                        <?php endif; ?>
	                        <?php if ( $settings['show_button'] ) : ?>
	                        <a class="btn circle btn-md btn-gradient wow fadeInUp" href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?> <i class="fas fa-angle-right"></i></a>
	                        <?php endif; ?>
	                    </div>
	                </div>
	            </div>
	        </div>
	        <div class="container">
	            <div class="blog-items">
	                <div class="row">
	                	<?php
			                $args = new \WP_Query(array(   
			                            'post_type' => 'post', 
			                        ));  
			                while ($wp_query -> have_posts()) : $wp_query -> the_post();  
			            ?>
	                    <!-- Single Item -->
	                    <div class="single-item col-lg-4 col-md-6">
	                        <div class="item">
	                            <div class="thumb">
	                                <a href="<?php the_permalink(); ?>">
	                                    <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="Thumb">
	                                </a>
	                            </div>
	                            <div class="info">
	                                <div class="meta">
	                                    <ul>
	                                        <li><?php the_time(get_option( 'date_format' ));?></li>
	                                        <li><?php the_author_posts_link(); ?></li>
	                                    </ul>
	                                </div>
	                                <h4>
	                                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?> </a>
	                                </h4>
	                                <p>
	                                    <?php if(isset($poora_redux_demo['blog_excerpt'])){?>
						                <?php echo esc_attr(poora_excerpt($poora_redux_demo['blog_excerpt'])); ?>
						                <?php }else{?>
						                <?php echo esc_attr(poora_excerpt(30)); 
						                ?> 
						            	<?php } ?>
	                                </p>

	                                <a class="btn-more" href="<?php the_permalink(); ?>"><?php if(isset($poora_redux_demo['read_more'])){?>
	                                <?php echo wp_specialchars_decode(esc_attr($poora_redux_demo['read_more']));?>
	                                <?php }else{?>
	                                <?php echo esc_html__( 'Read More', 'poora' );?>
                                	<?php } ?>
                                		
                                	</a>
	                            </div>
	                        </div>
	                    </div>
	                    <!-- End Single Item -->
	                    <?php   
					        endwhile; 
					        wp_reset_postdata();
					    ?>
	                </div>
	            </div>
	        </div>
	    </div>
	    <!-- End Blog Area -->
	<?php
	}

}