<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsProjectVersionThree extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-project-three';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Project Version Three', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Project widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Project widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'project' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Project Version Three', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Projects Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '3',
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings);
		$post_number = $settings['post_number'];
	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'Donation',  'orderby' => 'ID', 'order' => 'ASC'));
	   
	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'Donation',  'orderby' => 'ID', 'order' => 'ASC');
		?>
		<div class="wide-causes-area causes-area bg-gray">
	        <div class="carouses-items causes-items wide-causes-carousel owl-carousel owl-theme">
	        	<?php
	                $args = new \WP_Query(array(   
	                            'post_type' => 'Donation', 
	                        ));  
	                while ($wp_query -> have_posts()) : $wp_query -> the_post();
	                $raised = get_post_meta(get_the_ID(),'_cmb_raised', true);
					$goal = get_post_meta(get_the_ID(),'_cmb_goal', true);
					$percent = get_post_meta(get_the_ID(),'_cmb_percent', true);
					$location = get_post_meta(get_the_ID(),'_cmb_location', true);
					$project_image = get_post_meta(get_the_ID(),'_cmb_project_image', true);
	            ?>
	            <!-- Single Item -->
	            <div class="item">
	                <div class="row">
	                    <div class="col-lg-6 thumb" style="background-image: url(<?php print wp_get_attachment_url($project_image); ?>);"></div>
	                    <div class="col-lg-6 info">
	                        <div class="top-entry">
	                            <div class="date">
	                                <i class="fas fa-clock"></i> <strong><?php the_time(get_option( 'date_format' ));?> </strong>
	                            </div>
	                            <div class="location">
	                                <i class="fas fa-map-marker-alt"></i> <strong><?php echo esc_attr($location); ?> </strong>
	                            </div>
	                        </div>
	                        <h3>
	                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
	                        </h3>
	                        <p>
                                <?php if(isset($poora_redux_demo['blog_excerpt'])){?>
				                <?php echo esc_attr(poora_excerpt($poora_redux_demo['blog_excerpt'])); ?>
				                <?php }else{?>
				                <?php echo esc_attr(poora_excerpt(30)); 
				                ?> 
				            	<?php } ?> 
                            </p>
	                        <div class="progress-box">
	                            <div class="progress">
	                                <div class="progress-bar" role="progressbar" style="width:<?php echo esc_attr($percent); ?>%">
	                                    <span class="progress-bar wow fadeInLeft"><?php echo esc_attr($percent); ?>%</span>
	                                </div>
	                            </div>
	                            <p><?php echo esc_attr($raised); ?> <span><?php echo esc_attr($goal); ?></span></p>
	                        </div>
	                        <a class="btn circle btn-theme border btn-md" href="<?php the_permalink(); ?>">
                            	<?php if(isset($poora_redux_demo['project_read_more'])){?>
                                <?php echo wp_specialchars_decode(esc_attr($poora_redux_demo['project_read_more']));?>
                                <?php }else{?>
                                <?php echo esc_html__( 'Donate Now', 'poora' );?>
                            	<?php } ?>
                            </a>
	                    </div>
	                </div>
	            </div>
	            <!-- End Single Item -->
	            <?php   
			        endwhile; 
			        wp_reset_postdata();
			    ?>
	        </div>
	    </div>
<?php if (is_admin()) { ?>
<script type="text/javascript">
   $('.wide-causes-carousel').owlCarousel({
            loop: false,
            nav: true,
            margin:30,
            dots: false,
            autoplay: true,
            items: 1,
            navText: [
                "<i class='fa fa-angle-left'></i>",
                "<i class='fa fa-angle-right'></i>"
            ]
        });
</script>
<?php }  ?>
	<?php
	}

}