<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsSliderVersionTwo extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-slider-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Slider Version Two', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slideshow';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'slider', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Slider Version Two', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),
					],
					[
						'name'        => 'heading',
						'label'       => esc_html__( 'Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'subheading',
						'label'       => esc_html__( 'Subheading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is subheading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'button',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is button' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link_button',
						'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();


	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>
		<!-- Start Banner 
	    ============================================= -->
	    <div class="banner-area top-pad-150 text-center text-large">
	        <div id="bootcarousel" class="carousel text-light slide carousel-fade animate_text" data-ride="carousel">

	            <!-- Wrapper for slides -->
	            <div class="carousel-inner carousel-zoom">
	            	<?php $i=0;
	                    foreach ( $settings['tabs'] as $item ) : 
	                    $i ++;
					?>
					<?php if($i ==1){ ?>
	                <div class="carousel-item active">
	                    <div class="slider-thumb bg-cover" style="background-image: url(<?php echo wp_kses_post($item['tab_image']['url']); ?>);"></div>
	                    <div class="box-table">
	                        <div class="box-cell shadow dark">
	                            <div class="container">
	                                <div class="row">
	                                    <div class="col-lg-10 offset-lg-1">
	                                        <div class="content">
	                                        	<?php if ( $settings['show_heading'] ) : ?>
	                                            <h2 data-animation="animated slideInRight"><?php print wp_kses_post($item['heading']); ?></h2>
	                                            <?php endif; ?>
	                                            <?php if ( $settings['show_subheading'] ) : ?>
	                                            <p data-animation="animated slideInLeft">
	                                                <?php print wp_kses_post($item['subheading']); ?>
	                                            </p>
	                                            <?php endif; ?>
	                                            <?php if ( $settings['show_button'] ) : ?>
	                                            <a data-animation="animated fadeInUp" class="btn circle btn-theme border btn-md" href="<?php print wp_kses_post($item['link_button']); ?>"><?php print wp_kses_post($item['button']); ?></a>
	                                        	<?php endif; ?>
	                                        </div>
	                                    </div>
	                                </div>
	                            </div>
	                        </div>
	                    </div>
	                </div>
	                <?php }else{ ?>
	                <div class="carousel-item">
	                    <div class="slider-thumb bg-cover" style="background-image: url(<?php echo wp_kses_post($item['tab_image']['url']); ?>);"></div>
	                    <div class="box-table">
	                        <div class="box-cell shadow dark">
	                            <div class="container">
	                                <div class="row">
	                                    <div class="col-lg-10 offset-lg-1">
	                                        <div class="content">
	                                        	<?php if ( $settings['show_heading'] ) : ?>
	                                            <h2 data-animation="animated slideInRight"><?php print wp_kses_post($item['heading']); ?></h2>
	                                            <?php endif; ?>
	                                            <?php if ( $settings['show_subheading'] ) : ?>
	                                            <p data-animation="animated slideInLeft">
	                                                <?php print wp_kses_post($item['subheading']); ?>
	                                            </p>
	                                            <?php endif; ?>
	                                            <?php if ( $settings['show_button'] ) : ?>
	                                            <a data-animation="animated fadeInUp" class="btn circle btn-theme border btn-md" href="<?php print wp_kses_post($item['link_button']); ?>"><?php print wp_kses_post($item['button']); ?></a>
	                                        	<?php endif; ?>
	                                        </div>
	                                    </div>
	                                </div>
	                            </div>
	                        </div>
	                    </div>
	                </div>
	            	<?php } ?>
	            	<?php endforeach; ?>
	            </div>
	            <!-- End Wrapper for slides -->

	            <!-- Left and right controls -->
	            <a class="left carousel-control light" href="#bootcarousel" data-slide="prev">
	                <i class="fa fa-angle-left"></i>
	                <span class="sr-only">Previous</span>
	            </a>
	            <a class="right carousel-control light" href="#bootcarousel" data-slide="next">
	                <i class="fa fa-angle-right"></i>
	                <span class="sr-only">Next</span>
	            </a>

	        </div>
	    </div>
	    <!-- End Banner -->
	<?php
	}

}