<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTabs extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-tabs';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Tabs', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Banner widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-tabs';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Banner widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'tabs' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Tabs', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'background_bg',
			[
				'label'   => esc_html__( 'Featured Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'background_bg_2',
			[
				'label'   => esc_html__( 'Featured Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'background_bg_3',
			[
				'label'   => esc_html__( 'Featured Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Heading', 'bdevs-elementor' ),
				'default'     => __( 'This is heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Subheading', 'bdevs-elementor' ),
				'default'     => __( 'This is subheading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_tabs',
			[
				'label' => esc_html__( 'Tabs Title', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_tabs2',
			[
				'label' => esc_html__( 'Tabs Content', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'        => 'title_2',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'content',
						'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'        => Controls_Manager::WYSIWYG,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is content' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'button',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Button' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link_button',
						'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();


		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings);?>
		<div class="target-area default-padding">
	        <div class="container">
	            <div class="row">
	                <div class="col-lg-6">
	                    <div class="thumb">
	                        <div class="row">
	                            <div class="col-lg-6 item-grid">
	                                <img src="<?php print esc_url( $settings['background_bg']['url'] ); ?>" alt="Thumb1">
	                                <img src="<?php print esc_url( $settings['background_bg_2']['url'] ); ?>" alt="Thumb2">
	                            </div>
	                            <div class="col-lg-6 item-grid">
	                                <img src="<?php print esc_url( $settings['background_bg_3']['url'] ); ?>" alt="Thumb3">
	                                <div class="content">
	                                	<?php if ( $settings['show_heading'] ) : ?>
	                                    <h4><?php print wp_kses_post($settings['heading']); ?></h4>
	                                	<?php endif; ?>
	                                    <?php if ( $settings['show_subheading'] ) : ?>
	                                    <a href="#"><?php print wp_kses_post($settings['subheading']); ?></a>
	                                    <?php endif; ?>
	                                </div>
	                            </div>
	                        </div>
	                    </div>
	                </div>
	                <div class="col-lg-6 tab-items">
	                    <ul id="tabs" class="nav nav-tabs">
	                    	<?php $i =0;
			                    foreach ( $settings['tabs'] as $item ) : 
			                    $i++;
							?>
							<?php if($i == 1){ ?>
	                        <li class="nav-item">
	                            <a href="" data-target="#tab1" data-toggle="tab" class="active nav-link"><?php print wp_kses_post($item['title']); ?></a>
	                        </li>
	                    	<?php }elseif($i == 2){ ?>
	                        <li class="nav-item">
	                            <a href="" data-target="#tab2" data-toggle="tab" class="nav-link"><?php print wp_kses_post($item['title']); ?></a>
	                        </li>
	                        <?php }elseif($i == 3){ ?>
	                        <li class="nav-item">
	                            <a href="" data-target="#tab3" data-toggle="tab" class="nav-link"><?php print wp_kses_post($item['title']); ?></a>
	                        </li>
	                    	<?php }else{ ?>
	                    	<li class="nav-item">
	                            <a href="" data-target="#tab4" data-toggle="tab" class="nav-link"><?php print wp_kses_post($item['title']); ?></a>
	                        </li>
	                        <?php } ?>
	                    	<?php endforeach; ?>
	                    </ul>
	                    <div id="tabsContent" class="tab-content">
	                    	<?php $j =0;
			                    foreach ( $settings['tabs2'] as $item ) : 
			                    $j++;
							?>
							<?php if($j == 1){ ?>
	                        <div id="tab1" class="tab-pane fade active show">
	                            <div class="row align-center">
	                                <div class="col-lg-12 info">
	                                    <h2><?php print wp_kses_post($item['title_2']); ?></h2>
	                                    <?php if ( '' !== $item['content'] ) : ?>
	                                    <?php print wp_kses_post($item['content']); ?>
	                                    <?php endif; ?>
	                                    <?php if ( '' !== $item['button'] ) : ?>
	                                    <a class="btn circle btn-theme border btn-sm" href="<?php print wp_kses_post($item['link_button']); ?>"><?php print wp_kses_post($item['button']); ?></a>
	                                	<?php endif; ?>
	                                </div>
	                            </div>
	                        </div>
	                    	<?php }elseif($j == 2){ ?>
	                        <div id="tab2" class="tab-pane fade">
	                            <div class="row align-center">
	                                <div class="col-lg-12 info">
	                                    <h2><?php print wp_kses_post($item['title_2']); ?></h2>
	                                    <?php if ( '' !== $item['content'] ) : ?>
	                                    <?php print wp_kses_post($item['content']); ?>
	                                    <?php endif; ?>
	                                    <?php if ( '' !== $item['button'] ) : ?>
	                                    <a class="btn circle btn-theme border btn-sm" href="<?php print wp_kses_post($item['link_button']); ?>"><?php print wp_kses_post($item['button']); ?></a>
	                                	<?php endif; ?>
	                                </div>
	                            </div>
	                        </div>
	                        <?php }elseif($j == 3){ ?>
	                        <div id="tab3" class="tab-pane fade">
	                            <div class="row align-center">
	                                <div class="col-lg-12 info">
	                                    <h2><?php print wp_kses_post($item['heading']); ?></h2>
	                                    <?php if ( '' !== $item['content'] ) : ?>
	                                    <?php print wp_kses_post($item['content']); ?>
	                                    <?php endif; ?>
	                                    <?php if ( '' !== $item['button'] ) : ?>
	                                    <a class="btn circle btn-theme border btn-sm" href="<?php print wp_kses_post($item['link_button']); ?>"><?php print wp_kses_post($item['button']); ?></a>
	                                	<?php endif; ?>
	                                </div>
	                            </div>
	                        </div>
	                        <?php }else{ ?>
	                        <div id="tab4" class="tab-pane fade">
	                            <div class="row align-center">
	                                <div class="col-lg-12 info">
	                                    <h2><?php print wp_kses_post($item['heading']); ?></h2>
	                                    <?php if ( '' !== $item['content'] ) : ?>
	                                    <?php print wp_kses_post($item['content']); ?>
	                                    <?php endif; ?>
	                                    <?php if ( '' !== $item['button'] ) : ?>
	                                    <a class="btn circle btn-theme border btn-sm" href="<?php print wp_kses_post($item['link_button']); ?>"><?php print wp_kses_post($item['button']); ?></a>
	                                	<?php endif; ?>
	                                </div>
	                            </div>
	                        </div>
	                    	<?php } ?>
	                    	<?php endforeach; ?>
	                    </div>
	                </div>
	            </div>
	        </div>
	    </div>
	<?php
	}

}