<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTeam extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-team';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-person';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Team widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'team' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Team', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'team_style_1'  => esc_html__( 'Team Normal', 'bdevs-elementor' ),
					'team_style_2' => esc_html__( 'Team Carousel', 'bdevs-elementor' ),
				],
				'default'   => 'team_style_1',
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
				'default'     => __( 'This is subheading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'This is heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_team',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => __( '', 'bdevs-elementor' ),
					],
					[
						'name'        => 'name',
						'label'       => esc_html__( 'Name', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Name' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'info',
						'label'       => esc_html__( 'Info', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Info' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link_facebook',
						'label'       => esc_html__( 'Link Facebook', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link_twitter',
						'label'       => esc_html__( 'Link Twitter', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link_instagram',
						'label'       => esc_html__( 'Link Instagram', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();


		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();	
		extract($settings); ?>
		<?php if( $chose_style == 'team_style_1' ): ?>
		<!-- Start Voluntter 
	    ============================================= -->
	    <div class="volunteer-area default-padding bottom-less">
	        <div class="container">
	            <div class="row">
	                <div class="col-lg-8 offset-lg-2">
	                    <div class="site-heading text-center">
	                        <?php if ( $settings['show_subheading'] ) : ?>
			                <h5><?php print wp_kses_post($settings['subheading']); ?></h5>
			                <?php endif; ?>
	                        <?php if ( $settings['show_heading'] ) : ?>
			                <h2><?php print wp_kses_post($settings['heading']); ?></h2>
			                <div class="heading-divider"></div>
			                <?php endif; ?>
	                        
	                    </div>
	                </div>
	            </div>
	        </div>
	        <div class="container">
	            <div class="volunteer-items text-center">
	                <div class="row">
	                	<?php 
		                    foreach ( $settings['tabs'] as $item ) : 
						?>
	                    <!-- Single Item -->
	                    <div class="single-item col-lg-4 col-md-6">
	                        <div class="item">
	                            <div class="thumb">
	                                <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="Thumb">
	                                <div class="social">
	                                    <ul>
	                                        <li>
	                                            <a href="<?php print wp_kses_post($item['link_facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
	                                        </li>
	                                        <li>
	                                            <a href="<?php print wp_kses_post($item['link_twitter']); ?>"><i class="fab fa-twitter"></i></a>
	                                        </li>
	                                        <li>
	                                            <a href="<?php print wp_kses_post($item['link_instagram']); ?>"><i class="fab fa-instagram"></i></a>
	                                        </li>
	                                    </ul>
	                                </div>
	                            </div>
	                            <div class="info">
	                                <h4><?php print wp_kses_post($item['name']); ?></h4>
	                                <span><?php print wp_kses_post($item['info']); ?></span>
	                            </div>
	                        </div>
	                    </div>
	                    <!-- End Single Item -->
	                    <?php endforeach; ?>
	                </div>
	            </div>
	        </div>
	    </div>
	    <!-- End Voluntter -->
        <?php elseif( $chose_style == 'team_style_2' ): ?>
        <div class="volunteer-area bg-gray default-padding">
	        <div class="container">
	            <div class="row">
	                <div class="col-lg-8 offset-lg-2">
	                    <div class="site-heading text-center">
	                        <?php if ( $settings['show_subheading'] ) : ?>
			                <h5><?php print wp_kses_post($settings['subheading']); ?></h5>
			                <?php endif; ?>
	                        <?php if ( $settings['show_heading'] ) : ?>
			                <h2><?php print wp_kses_post($settings['heading']); ?></h2>
			                <div class="heading-divider"></div>
			                <?php endif; ?>
	                    </div>
	                </div>
	            </div>
	        </div>
	        <div class="container">
	            <div class="volunteer-items volunteer-carousel owl-carousel owl-theme text-center">
            		<?php 
	                    foreach ( $settings['tabs'] as $item ) : 
					?>
                    <div class="item">
                        <div class="thumb">
                            <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="Thumb">
                            <div class="social">
                                <ul>
                                    <li>
                                        <a href="<?php print wp_kses_post($item['link_facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
                                    </li>
                                    <li>
                                        <a href="<?php print wp_kses_post($item['link_twitter']); ?>"><i class="fab fa-twitter"></i></a>
                                    </li>
                                    <li>
                                        <a href="<?php print wp_kses_post($item['link_instagram']); ?>"><i class="fab fa-instagram"></i></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="info">
                            <h4><?php print wp_kses_post($item['name']); ?></h4>
                            <span><?php print wp_kses_post($item['info']); ?></span>
                        </div>
                    </div>
                    <?php endforeach; ?>

	            </div>
	        </div>
	    </div>
<?php if (is_admin()) { ?>
<script type="text/javascript">
   $('.volunteer-carousel').owlCarousel({
            loop: false,
            margin: 30,
            nav: false,
            navText: [
                "<i class='fa fa-angle-left'></i>",
                "<i class='fa fa-angle-right'></i>"
            ],
            dots: true,
            autoplay: true,
            responsive: {
                0: {
                    items: 1
                },
                800: {
                    items: 2
                },
                1000: {
                    items: 3
                }
            }
        });
</script>
<?php }  ?>
		<?php endif; ?>
	<?php
	}

}